# @Time : 2020/11/13 10:18 

# @Author : Cuiluming

# @File : locust_get_runlog.py

# @Software: PyCharm

import io
import platform
import os, sys
from accio.conn_influxdb import ConnectInfluxDB
import threading
import time
from . import config_file_parser,parse_tools

interval = 3
conf = config_file_parser.ConfigFileParserIni()
time1=conf.get_value("locust_report","time")
start_time=int(time.time())
end_time=start_time+int(time1)*60


def read_file():
    locust_list = []
    # BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))  # 项目目录
    BASE_DIR = parse_tools.Parse.get_rootpath()
    curPath = os.path.abspath(os.path.dirname(__file__))  # 项目名称
    rootPath = os.path.split(curPath)[0] + '\\' + os.path.split(curPath)[1]
    sys.path.append(rootPath)
    pattern = '/' if platform.system() != 'Windows' else '\\'
    performance_path = os.path.join(BASE_DIR, 'log' + pattern + "run.log")
    # print(performance_path)
    influxdb = ConnectInfluxDB()
    with io.open(performance_path) as f:
        data_list = f.readlines()
        i=0
        for data in data_list:
            splits = data.split()
            # print("splits :%s" % splits)
            temp = []
            for s in splits:
                if s.replace(" ", "").strip('\n').strip('|').__len__() != 0:
                    temp.append(s)
                    # print(temp)
            if len(temp) > 1 and (temp[0] == 'POST' or temp[0] == 'GET'):
                # print("进入res")
                # print(temp)
                method = temp[0]
                api = temp[1]
                reqs = temp[2]
                fails = temp[3]
                Avg = temp[4]
                Min = temp[5]
                Max = temp[6]
                Median = temp[7]
                qps = temp[8]
                failures = temp[9]
                # ninety_percent=float(temp[10])
                # ninety_five_percent= float(temp[11])
                # ninety_nine_percent=float(temp[13])
                locust_dict = {'Method': method, 'Name': api, 'Requests': reqs, 'Fails': fails, 'Average_ms': Avg,
                               'Min_ms': Min, 'Max_ms': Max, 'Median_ms': Median, 'Current_RPS': qps,
                               'Failures_s': failures,}
                locust_list.append(locust_dict)
            if len(temp) > 1 and temp[0] == 'Aggregated':
                # print("进入Aggregated")
                # print("Aggregated:%s" % temp)
                method = temp[0]
                api = temp[0]
                reqs = temp[1]
                fails = temp[2]
                Avg = temp[3]
                Min = temp[4]
                Max = temp[5]
                Median = temp[6]
                qps = temp[7]
                failures = temp[8]
                locust_dict = {'Method': method, 'Name': api, 'Requests': reqs, 'Fails': fails, 'Average_ms': Avg,
                               'Min_ms': Min, 'Max_ms': Max, 'Median_ms': Median, 'Current_RPS': qps,
                               'Failures_s': failures}
                locust_list.append(locust_dict)
        influxdb.post_dump_data(locust_list, "locust")
    # return locust_dict


def monitor(project_name):
    print("start monitoring")
    read_file()
    timer = threading.Timer(interval, monitor, args=[project_name])
    timer.start()
    start_time = int(time.time())
    if(start_time<=end_time):
        print(start_time,end_time)
        pass
    else:
        timer.cancel()


def start(*args, **kwargs):
    timer = threading.Timer(interval, monitor, args=args, kwargs=kwargs)
    print("start=====")
    timer.start()

# if __name__ == '__main__':
#     locust_result().read_file()


# -*- coding: utf-8 -*-
# @File    : Consts.py

"""
接口全局变量

"""

# 接口全局配置
API_ENVIRONMENT_DEBUG = 'debug'
API_ENVIRONMENT_RELEASE = 'release'

# 接口响应时间list，单位毫秒
STRESS_LIST = []

# 接口执行结果list
RESULT_LIST = []




from influxdb import InfluxDBClient


class ConnectInfluxDB:
    """
    连接influxdb数据库
    """

    def __init__(self):
        self.influx_client = InfluxDBClient('10.39.32.50', 31273, '', '', 'influxdb')
        self.make = False
        for database in self.influx_client.get_list_database():
            if "influxdb" not in database["name"]:
                self.make = True
            else:
                # 写入前删除数据
                self.influx_client.drop_measurement("locust")
                self.make = False
        if self.make:
            self.influx_client.create_database("influxdb")

    def post_dump_data(self, data, measurement):
        """

        @param data:返回的list
        @param measurement:
        """
        if isinstance(data, list):
            for key in data:
                json_body = [
                    {
                        "measurement": measurement,
                        "fields": key,
                    }
                ]
                self.influx_client.write_points(json_body)

    def post_dump_data(self, data, table):
        """

        @param data:
        @param measurement: 表名
        """
        if isinstance(data, list):
            for key in data:
                json_body = [
                    {
                        "measurement": table,
                        "fields": key,
                    }
                ]
                self.influx_client.write_points(json_body)

# if __name__ == '__main__':
#     pass


# -*- coding: utf-8 -*-
# @File    : Http.py

"""
封装request

"""

import os
import random
import requests
import accio.Consts
from . import Session
from requests_toolbelt import MultipartEncoder


class Request(object):

    def __init__(self):
        """
        :param
        """
        self.get_session = {}

    def get(self, url, data, header):
        """
        Get请求
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)

        try:
            if data is None:
                response = requests.get(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.get(url=url, params=data, headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        time_consuming = response.elapsed.microseconds/1000
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        response_dicts = dict()
        response_dicts['code'] = response.status_code
        try:
            response_dicts['body'] = response.json()
        except Exception as e:
            print(e)
            response_dicts['body'] = ''
        response_dicts['text'] = response.text
        response_dicts['time_consuming'] = time_consuming
        response_dicts['time_total'] = time_total

        return response_dicts

    def get_json(self, url, data, header):
        """
        Get请求,返回数据为json
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)

        try:
            if data is None:
                response = requests.get(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.get(url=url, params=data, headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        time_consuming = response.elapsed.microseconds/1000
        accio.Consts.STRESS_LIST.append(time_consuming)

        try:
            response_json = response.json()
        except Exception as e:
            print(e)

        return response_json

    def get_text(self, url, data, header):
        """
        Get请求,返回数据为text
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)

        try:
            if data is None:
                response = requests.get(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.get(url=url, params=data, headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        time_consuming = response.elapsed.microseconds/1000
        accio.Consts.STRESS_LIST.append(time_consuming)

        try:
            response_text = response.text
        except Exception as e:
            print(e)

        return response_text

    def post(self, url, data, header):
        """
        Post请求
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)
        try:
            if data is None:
                response = requests.post(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.post(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        # time_consuming为响应时间，单位为毫秒
        time_consuming = response.elapsed.microseconds/1000
        # time_total为响应时间，单位为秒
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        response_dicts = dict()
        response_dicts['code'] = response.status_code
        try:
            response_dicts['body'] = response.json()
        except Exception as e:
            print(e)
            response_dicts['body'] = ''

        response_dicts['text'] = response.text
        response_dicts['time_consuming'] = time_consuming
        response_dicts['time_total'] = time_total

        return response_dicts

    def post_json(self, url, data, header):
        """
        Post请求,返回数据格式为json
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)
        try:
            if data is None:
                response = requests.post(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.post(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        # time_consuming为响应时间，单位为毫秒
        time_consuming = response.elapsed.microseconds/1000
        # time_total为响应时间，单位为秒
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        try:
            response_json = response.json()
        except Exception as e:
            print(e)

        return response_json

    def post_text(self, url, data, header):
        """
        Post请求,返回数据格式为text
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)
        try:
            if data is None:
                response = requests.post(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.post(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        # time_consuming为响应时间，单位为毫秒
        time_consuming = response.elapsed.microseconds/1000
        # time_total为响应时间，单位为秒
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        try:
            response_text = response.text
        except Exception as e:
            print(e)

        return response_text

    def post_multipart(self, url, data, header, file_parm, file, f_type):
        """
        提交Multipart/form-data 格式的Post请求
        :param url:
        :param data:
        :param header:
        :param file_parm:
        :param file:
        :param type:
        :return:
        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)
        try:
            if data is None:
                response = requests.post(url=url, headers=header, cookies=self.get_session)
            else:
                data[file_parm] = os.path.basename(file), open(file, 'rb'), f_type

                enc = MultipartEncoder(
                    fields=data,
                    boundary='--------------' + str(random.randint(1e28, 1e29 - 1))
                )

                header['Content-Type'] = enc.content_type
                response = requests.post(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        # time_consuming为响应时间，单位为毫秒
        time_consuming = response.elapsed.microseconds/1000
        # time_total为响应时间，单位为秒
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        response_dicts = dict()
        response_dicts['code'] = response.status_code
        try:
            response_dicts['body'] = response.json()
        except Exception as e:
            print(e)
            response_dicts['body'] = ''

        response_dicts['text'] = response.text
        response_dicts['time_consuming'] = time_consuming
        response_dicts['time_total'] = time_total

        return response_dicts

    def put(self, url, data, header):
        """
        Put请求
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)

        try:
            if data is None:
                response = requests.put(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.put(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        time_consuming = response.elapsed.microseconds/1000
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        response_dicts = dict()
        response_dicts['code'] = response.status_code
        try:
            response_dicts['body'] = response.json()
        except Exception as e:
            print(e)
            response_dicts['body'] = ''
        response_dicts['text'] = response.text
        response_dicts['time_consuming'] = time_consuming
        response_dicts['time_total'] = time_total

        return response_dicts

    def put_json(self, url, data, header):
        """
        Put请求,返回数据为json
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)

        try:
            if data is None:
                response = requests.put(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.put(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        time_consuming = response.elapsed.microseconds/1000
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        try:
            response_json = response.json()
        except Exception as e:
            print(e)

        return response_json

    def put_text(self, url, data, header):
        """
        Put请求,返回数据为text
        :param url:
        :param data:
        :param header:
        :return:

        """
        if not url.startswith('http'):
            url = '%s%s' % ('http://', url)
            print(url)

        try:
            if data is None:
                response = requests.put(url=url, headers=header, cookies=self.get_session)
            else:
                response = requests.put(url=url, data=data.encode(), headers=header, cookies=self.get_session)

        except requests.RequestException as e:
            print('%s%s' % ('RequestException url: ', url))
            print(e)
            return ()

        except Exception as e:
            print('%s%s' % ('Exception url: ', url))
            print(e)
            return ()

        time_consuming = response.elapsed.microseconds/1000
        time_total = response.elapsed.total_seconds()

        accio.Consts.STRESS_LIST.append(time_consuming)

        try:
            response_text = response.text
        except Exception as e:
            print(e)

        return response_text



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    : analysis_postmanjson.py
@Time    : 2020/10/19 9:40
@Author  : Yu Tao
@Software: PyCharm
"""
import sys
from . import parse_tools
from urllib.parse import urlparse


class Postman(object):

    def source(self, postman_json):
        """
        生成测试用例
        :param postman_json:
        :return:
        """
        try:
            swagger_json, path_list = self.format_data(postman_json)
            parse_tools.Parse.tmp(swagger_json, 'a')
            parse_tools.Parse.tmp_create_case()
            # swagger_json参数表入参
            return path_list, swagger_json
        except Exception as ex:
            print('获取postman文件数据失败！')
            print(ex)
            sys.exit()

    def format_data(self, postman_json):
        """
        格式化数据，使其满足“用例生成”的调用要求
        :param file_context: 读出的json文件数据
        :return:
        """
        template_data = {"swagger": "2.0"}
        template_data.update({"basePath":""})
        template_data.update({"paths":{}})
        consumes = []
        path_list = []
        if isinstance(postman_json, dict):
            item_list = postman_json.get("item")
            for item in item_list:
                request = item.get("request")
                method = request.get("method").lower()
                header = request.get("header")
                if header:
                    for header_content in header:
                        if header_content.get("key") == "Content-Type":
                            consumes.append(header_content.get("value"))
                url = request.get("url")
                path = urlparse(url.get("raw")).path
                path_list.append(path)
                parameters = []
                if request.get("body"):
                    if eval(request.get("body").get("raw")).keys():
                        for key in eval(request.get("body").get("raw")).keys():
                            parameters.append({"name":key, "in":"body"})
                if url.get("query"):
                    for para in url.get("query"):
                        parameters.append({"name":para.get("key"), "in":"body"})
                template_data["paths"].update({path:{}})
                template_data["paths"][path].update({method:{"parameters":parameters, "consumes":consumes}})
        return template_data, path_list




#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    : analysis_jmx.py
@Time    : 2020/11/25 16:46
@Author  : Yu Tao
@Software: PyCharm
"""
import xml.etree.ElementTree as ET
from urllib.parse import urlparse
from . import parse_tools
import sys


class Jxm(object):

    def source(self, jmx_content):
        """
        生成测试用例
        :param jmx_content:
        :return:
        """
        try:
            swagger_json, path_list = self.format_data(jmx_content=jmx_content)
            parse_tools.Parse.tmp(swagger_json, 'a')
            parse_tools.Parse.tmp_create_case()
            # swagger_json参数表入参
            return path_list, swagger_json
        except Exception as ex:
            print('获取jmx文件数据失败！')
            print(ex)
            sys.exit()

    def format_data(self, jmx_content):
        """
        格式化数据，使其满足“用例生成”的调用要求
        :param jmx_content: 读出的jmx文件数据
        :return:
        """
        root = ET.fromstring(jmx_content)
        template_data = {"swagger": "2.0"}
        template_data.update({"basePath": ""})
        template_data.update({"paths": {}})
        path_list = []
        path = ""
        method = ""
        consumes_json = 0
        #更新json格式的情况：consumes字段赋值
        for HeaderManager in root.iter("HeaderManager"):
            content_type = 0
            for stringProp in HeaderManager.iter("stringProp"):
                if stringProp.attrib['name'] == 'Header.name' and stringProp.text == "Content-Type":
                    content_type = 1
                if content_type and stringProp.attrib['name'] == 'Header.value' and stringProp.text.find("application/json") != -1:
                    consumes_json = 1
        for HTTPSamplerProxy in root.iter("HTTPSamplerProxy"):
            consumes = []
            parameters = []
            boolProp_postBodyRaw = 0
            #获取接口中的path、method等
            for stringProp in HTTPSamplerProxy.iter("stringProp"):
                print(stringProp.tag, ":", stringProp.attrib)
                if stringProp.attrib['name'] == 'HTTPSampler.path' and stringProp.text is not None:
                    url = stringProp.text
                    path = urlparse(url).path
                    path_list.append(path)
                if stringProp.attrib['name'] == 'HTTPSampler.method' and stringProp.text is not None:
                    method = stringProp.text.lower()
            #解析jmeter的入参为：body data格式（<stringProp name="Argument.value">{&quot;username&quot;:&quot;yytest033&quot;,&quot;password&quot;:&quot;12345678&quot;}</stringProp>）
            if HTTPSamplerProxy.iter("boolProp"):
                for boolProp in HTTPSamplerProxy.iter("boolProp"):
                    if boolProp.attrib.get("name") == "HTTPSampler.postBodyRaw":
                        boolProp_postBodyRaw = 1
            if boolProp_postBodyRaw:
                for stringProp in HTTPSamplerProxy.iter("stringProp"):
                    if stringProp.attrib['name'] == 'Argument.value':
                        param_dict = eval(stringProp.text)
                        for param_key in param_dict.keys():
                            parameters.append({"name": param_key, "in": "body"})
            else:
                #解析jmeter的入参为：parameter格式
                for elementProp in HTTPSamplerProxy.iter("elementProp"):
                    if elementProp.attrib.get("elementType") == "HTTPArgument":
                        name = elementProp.attrib.get("name")
                        parameters.append({"name": name, "in":"body"})
            if consumes_json:
                consumes.append("application/json")
            template_data["paths"].update({path: {}})
            template_data["paths"][path].update({method: {"parameters": parameters, "consumes": consumes}})
        return template_data, path_list


# if __name__ == '__main__':
#     # with open('D:/yt/2message_api.jmx', 'r',encoding='utf-8') as f:
#     with open('D:/yt/Test Plan.jmx', 'r',encoding='utf-8') as f:
#         # print("=============================================")
#         # print(f.read())
#         # print("=============================================")
#         file_content = f.read()
#         Jxm().source(jmx_content=file_content)






# -*- encoding: utf-8 -*-
"""
@File    : TimedTasks.py
@Time    : 2020/9/9 9:38
@Author  : Yu Tao
@Software: PyCharm
"""

from apscheduler.schedulers.blocking import BlockingScheduler
from accio.config_file_parser import ConfigFileParserIni


class TimedTasks(object):

    def __init__(self, trigger=None):
        """
        初始化定时任务
        :param trigger: 触发器类型：interval、date、cron三种
        """
        if trigger is None:
            self.trigger = ConfigFileParserIni().get_value("scheduler", "trigger")
        elif trigger in ["interval", "date", "cron"]:
            self.trigger = trigger
        else:
            print("触发器输入有误。")
        self.cron = ConfigFileParserIni().get_value("scheduler", "time_pattern")

    def create_scheduler(self, job, time_pattern):
        """
        创建定时任务
        :param job: 任务
        :param time_pattern: 时间模式
        :return:
        """
        scheduler = BlockingScheduler()
        if self.trigger == "interval":
            scheduler.add_job(job, self.trigger, seconds=time_pattern)
        elif self.trigger == "date":
            scheduler.add_job(job, self.trigger, run_date=time_pattern)
        elif self.trigger == "cron":
            cronList = time_pattern.split(" ")
            scheduler.add_job(job, self.trigger, minutes=cronList[0], hours=cronList[1], date=cronList[2],
                              month=cronList[3], day_of_week=cronList[4])


# if __name__ == '__main__':
#     conf = TimedTasks("").create_scheduler()

    # while True:
    #     # print('main-start:', time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time())))
    #     time.sleep(2)
    #     # print('main-end:', time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time())))


# -*- coding: utf-8 -*-
# @File    : Hash.py
"""
封装各种加密方法

"""

from hashlib import sha1
from hashlib import md5
from Crypto.Hash import SHA256
from Crypto.Cipher import AES
from Crypto.Cipher import DES
import binascii


def md5(msg):
    """
    md5 算法加密
    :param msg: 需加密的字符串
    :return: 加密后的字符
    """
    hl = md5()
    hl.update(msg.encode('utf-8'))
    return hl.hexdigest()


def sha1(msg):
    """
    sha1 算法加密
    :param msg: 需加密的字符串
    :return: 加密后的字符
    """
    sh = sha1()
    sh.update(msg.encode('utf-8'))
    return sh.hexdigest()


def sha256(msg):
    """
    sha256 算法加密
    :param msg: 需加密的字符串
    :return: 加密后的字符
    """
    sh = SHA256.new()
    sh.update(msg.encode('utf-8'))
    return sh.hexdigest()


def des(msg, key):
    """
    DES 算法加密
    :param msg: 需加密的字符串,长度必须为8的倍数，不足添加'='
    :param key: 8个字符
    :return: 加密后的字符
    """
    de = DES.new(key, DES.MODE_ECB)
    mss = msg + (8 - (len(msg) % 8)) * '='
    text = de.encrypt(mss.encode())
    return binascii.b2a_hex(text).decode()


def aes_encrypt(msg, key, vi):
    """
    AES 算法的加密
    :param msg: 需加密的字符串
    :param key: 必须为16，24，32位
    :param vi: 必须为16位
    :return: 加密后的字符
    """
    obj = AES.new(key, AES.MODE_CBC, vi)
    txt = obj.encrypt(msg.encode())
    return binascii.b2a_hex(txt).decode()


def aes_decrypt(msg, key, vi):
    """
    AES 算法的解密
    :param msg: 需解密的字符串
    :param key: 必须为16，24，32位
    :param vi: 必须为16位
    :return: 加密后的字符
    """
    msg = binascii.a2b_hex(msg)
    obj = AES.new(key, AES.MODE_CBC, vi)
    return obj.decrypt(msg).decode()



# print(md5('wj123456'))


# -*- coding: utf-8 -*-
# @File    : Session.py

"""
封装获取cookie方法

"""

import requests
from . import logger


class Session(object):
    def __init__(self):
        self.log = logger.MyLog()

    def get_session(self, url, parm, headers):
        """
        获取session
        :param
        :return:
        """

        try:

            session_release = requests.session()
            response = session_release.post(url, parm, headers)
            print(response.cookies.get_dict())
            self.log.debug('cookies: %s' % response.cookies.get_dict())
            return response.cookies.get_dict()

        except:
            print("get cookies error")
            self.log.error('get cookies error, please checkout!!!')


# if __name__ == '__main__':
#     ss = Session()
#     ss.get_session('debug')


import os
from urllib.parse import urlparse
import sys
from . import  parse_tools
import re

class locust_template(object):
    def __init__(self):
        # self.root_path = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        self.root_path = os.path.dirname(os.path.join(os.getcwd()))

    def creat_dir(self):
        if not os.path.exists(self.root_path + '\\Performance'):
            os.makedirs(self.root_path + '\\Performance')

    def creat_template(self,root):
        file_path = self.root_path + "\\TestCase\\"
        f_list = os.listdir(file_path)
        self.creat_dir()
        test_case_file=parse_tools.Parse.find_casefile(file_path,f_list)
        r = ""
        file_list = []
        if len(test_case_file):
                for i in test_case_file:
                    file = file_path + str(i)
                    # print(file)
                    with open(file, encoding='utf-8') as outfile:
                        contents_str = outfile.read()
                        # print(file)
                        # 查找/开头" 结尾的任意字符串
                        convert_source = re.findall(r'/.*"', contents_str)
                        list_key_dict=parse_tools.Parse.extract_key(contents_str)
                        # list_key_dict=eval(list_key[0].replace(': ', ': "').replace(',', '",').replace('}', '"}'))
                        re_str=""
                        jshu=0
                        for yy in list_key_dict.keys():
                             re_str= re_str+"\""+yy+"\""+":out["+str(jshu)+"][count]"+","+"\r\n\t\t"
                             jshu +=1
                        #去掉最后一个逗号
                        re_str=re_str[:-5]
                        url = str(convert_source[0].replace('"', ""))
                        parse_url = urlparse(url)
                        url_path = parse_url.path
                        dir_path = parse_tools.Parse.path(url)
                        dir = root + '\\Performance\\{a}_locustfile.py'.format(a=dir_path)
                        if contents_str.find('request.post') != -1:
                            method = 'post'
                            body='data'
                        elif contents_str.find('request.get') != -1:
                            method = 'get'
                            body='params'
                        elif contents_str.find('request.put') != -1:
                            method = 'put'
                            body = 'data'
                        else:
                            raise Exception("该reques请求方式不是get\put\post")
                            sys.exit()
                    locustfile_templater = '''from locust import HttpUser, TaskSet, task,between
from accio import locust_read_parameterfile 
import os
import  json
import queue
from operator import itemgetter
#一次加载数据到队列
def queue_data():
    queue_data = queue.Queue()  # 默认为先进先出  该队列为task_set共享
    # queue.LifoQueue(),后进先出
    new_dict = locust_read_parameterfile.file_analysis.creatparm("loadfile.xlsx")
    key_list=[]
    count=0
    for k,v in new_dict.items():
        key_list.append(k)
    #一次读入多列值
    out = itemgetter(*key_list)(new_dict)
    max_len=0
    for i in out:
        if max_len< len(i):
            max_len=len(i)

    for i  in  range(max_len):
        params = {
         #取第一列的值 
        %s
        }
        count +=1
        queue_data.put_nowait(params)  # put_nowait 不阻塞
    return queue_data

def profile(self):
            # get_nowait() 取不到数据直接崩溃；get() 取不到数据会一直等待
            try:
                data=self.user.queue_data_test.get_nowait()
            except queue.Empty:  # 取不到数据时，走这里
                print('数据跑完了，任务结束')
                exit(0)
            params = json.dumps(data,ensure_ascii=False)            
            headers={}  
            with self.client.%s(url='%s', %s=params,headers=headers, catch_response=True) as response:
                if "success"in response.text:
                    response.success()
                else:
                    response.failure(response.text)
            self.user.queue_data_test.put_nowait(data)  # 把取出来的数据重新加入队列

class locustfile(TaskSet):
        def on_start(self):
            # 虚拟用户启动Task时运行
            print('虚拟用户启动Task时运行start')

        def on_stop(self):
            # 虚拟用户结束Task时运行
            print('虚拟用户结束Task时运行end')
        #压测接口，设置权重值，默认为1，值越大，优先执行
        tasks = {profile: 1}

class WebsiteUser(HttpUser):
        host = "http://gw.enncloud.cn/"
        tasks = [locustfile]
        #调用队列方法
        queue_data_test = queue_data()
        # 单位为秒
        wait_time = between(5, 6)
'''%(re_str,method,url_path,body)
                    wf = locustfile_templater
                    with open(dir, 'w', encoding="utf-8") as outfile:
                        outfile.write(str(wf))
        else:
            print('请确认TestCase文件夹下是否存在test 前缀文件！')
            sys.exit()

# if __name__ == '__main__':
#     l=locust_template()
#     ll=l.root_path
#     l.creat_template(ll)


# @Time : 2020/11/17 11:04

# @Author : Cuiluming

# @File : demo.py

# @Software: PyCharm
import csv
import pymysql
import time
import  os
from . import config_file_parser
from random import randint
# curPath = os.path.abspath(os.path.dirname(__file__))  # 项目名称
# rootPath = os.path.split(curPath)[0]
class  ReadCvs(object):
    def __init__(self,conn):
        self.rootPath=os.path.join(os.getcwd())
        self.csv_file_path =os.path.join(self.rootPath ,'Log','locusts_report_stats.csv')
        self.csv_file_path_fail =os.path.join(self.rootPath ,'Log','locusts_report_failures.csv')
        self.table_name_request = "webside_locust_result"
        self.table_name_fail = "webside_locust_fail_result"
        # db="accio"
        # self.user_name="崔"#压测作者需要传值
        self.now = int(time.time())
        self.creat_time = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime())
        # self.conf = config_file_parser.ConfigFileParserIni()
        # print(self.conf)
        self.host = conn['host']
        self.user = conn['username']
        self.passwd =  conn['password']
        self.db= conn['db']
        self.conn = pymysql.connect(user=self.user,
                       passwd=self.passwd,
                       db=self.db,
                       host=self.host,
                       local_infile=1)

    def read_csv(self,filename):
        read_list = []
        with open(filename) as f:
            f_csv = csv.reader(f)
            while True:
                try:
                    # 获得下一个值:
                    x = next(f_csv)
                    if len(x) == 0:
                        pass
                    else:
                        read_list.append(x)
                except StopIteration:
                    # 遇到StopIteration就退出循环
                    break
            # print("read_csv",read_list)
        return read_list
    
    def conn_to_psto(self):
    
        self.conn.set_charset('utf8')
        self.cur = self.conn.cursor()
        self.cur.execute("set names utf8")
        self.cur.execute("SET character_set_connection=utf8;")
        return self.cur
    
    def  mysql_insert(self,author, performance_file_alis,times,user,proid):
        if not os.path.exists(os.path.join(self.rootPath , 'Log')):
           os.makedirs(os.path.join(self.rootPath , 'Log'))
        f_csv = self.read_csv(self.csv_file_path)
        f_csv_file = self.read_csv(self.csv_file_path_fail)
        cur = self.conn_to_psto()
        now = int(time.time())
        creat_time=time.strftime('%Y-%m-%d %H:%M:%S', time.localtime())
        # print(creat_time)
        for row in f_csv[1:]:
            # print (row)
            try:
                # sql = '''insert into %s (Type,Name,RequestCount,FailureCount,MedianResponseTime,AverageResponseTime,MinResponseTime,MaxResponseTime,AverageContentSize,Requests_s,Failures_s,Fifty_percent,sixty_six_percent,seventy_five_percent,eighty_percent,ninety_percent,ninety_five_percent,ninety_eight_percent,ninety_nine_percent,ninety_nine_point_nine_percent,ninety_nine_point_nine_nine_percent,one_hundred_percent,systime,user_name,creat_time,delete_flag,SceneName,user,times,proid)values(%s,%s,%d,%d,%f,%f,%d,%d,%d,%f,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%s,%s,%s,%s,%s,%s,%s,%s) ''' \
                #       %(self.table_name_request,str("'" + row[0] + "'"), str("'" + row[1] + "'"), int(row[2]), int(row[3]), float(row[4]),\
                #       float(row[5]), float(row[6]), float(row[7]), float(row[8].replace('.0','')), float(row[9]), float(row[10]), int(row[11]),\
                #       int(row[12]), int(row[13]), int(row[14]), int(row[15]), int(row[16]), int(row[17]), int(row[18]),\
                #       int(row[19]), int(row[20]), int(row[21]),  now,"'" + author+"'", "'" + self.creat_time+"'","0","'" + performance_file_alis+"'","'" + user+"'","'" + times+"'","'" + proid+"'")
                # print(sql)
                sql = '''insert into %s (Type,Name,RequestCount,FailureCount,MedianResponseTime,AverageResponseTime,MinResponseTime,MaxResponseTime,AverageContentSize,Requests_s,Failures_s,Fifty_percent,sixty_six_percent,seventy_five_percent,eighty_percent,ninety_percent,ninety_five_percent,ninety_eight_percent,ninety_nine_percent,ninety_nine_point_nine_percent,ninety_nine_point_nine_nine_percent,one_hundred_percent,systime,user_name,creat_time,delete_flag,SceneName,user,times,proid)values(%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s,%s) ''' \
                      %(self.table_name_request,str("'" + row[0] + "'"), str("'" + row[1] + "'"),  str("'" + row[2] + "'"), str("'" + row[3] + "'"),  str("'" + row[4] + "'"),str("'" + row[5] + "'"),  str("'" + row[6] + "'"), str("'" + row[7] + "'"),  str("'" + row[8] + "'"), str("'" + row[9] + "'"), str("'" + row[10] + "'"),  str("'" + row[11] + "'"),str("'" + row[12] + "'"), str("'" + row[13] + "'"),  str("'" + row[14] + "'"),  str("'" + row[15] + "'"), str("'" + row[16] + "'"),  str("'" + row[17] + "'"), str("'" + row[18] + "'"),str("'" + row[19] + "'"), str("'" + row[20] + "'"),  str("'" + row[21] + "'"),  now,"'" + author+"'", "'" + self.creat_time+"'","0","'" + performance_file_alis+"'","'" + user+"'","'" + times+"'","'" + proid+"'")
                print(sql)
                cur.execute(sql)
                self.conn.commit()
            except  Exception as e:
                print(e)
                print("发生数据错误")
                self.conn.rollback()
            finally:
                pass
          
        for row in f_csv_file[1:]:
            # if len(row)==0:
            #     pass
            print("失败=======")
            try:
                sql = '''insert into %s (Method,Name,Error,Occurrences,systime,user_name,creat_time,delete_flag,SceneName)values(%s,%s,%s,%d,%s,%s,%s,%s,%s) ''' \
                      % (self.table_name_fail, str("'" + row[0] + "'"), str("'" + row[1] + "'"), str("'" + row[2] + "'"),
                         int(row[3]), now, "'" +  author + "'", "'" +  self.creat_time + "'","0","'" +  performance_file_alis + "'")
                print(sql)
                cur.execute(sql)
                self.conn.commit()
            except  Exception as e:
                print(e)
                print("发生数据错误")
                self.conn.rollback()
            finally:
                pass

        self.conn.close()

# if __name__ == "__main__":
#     mysql_insert()
#     mysql_insert_fails()


# @Time : 2020/11/12 14:13

# @Author : Cuiluming

# @File : locust_run.py

# @Software: PyCharm

import subprocess
from . import locust_get_runlog
import threading
from . import config_file_parser
import os
# import platform


def run(file,time,user):
    # BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))  # 项目目录
    BASE_DIR = os.path.dirname(os.path.join(os.getcwd()))
    # pattern = '/' if platform.system() != 'Windows' else '\\'
    if not os.path.exists(BASE_DIR + '\\log'):
        os.makedirs(BASE_DIR + '\\log')
    t1 = threading.Thread(target=locust_get_runlog.start("locust_monitoring"), args=())
    t1.start()
    try:
        a = subprocess.call('locust -f ..\\Performance\\{} --headless -u {} -r 5 -t {}m  --csv=..\\log\\locusts_report  --logfile=..\\log\\locust.log --loglevel=INFO 1>..\\log\\stdout.log  2>..\\log\\run.log '.format(file, user, time),
                              shell=True
                             )
        print("===========")
    except Exception as e:
        print(e)
    return a


# if __name__ == '__main__':
#     conf = config_file_parser.ConfigFileParserIni()
#     file = conf.get_value("locust_report","file")
#     time=conf.get_value("locust_report","time")
#     user=conf.get_value("locust_report", "user")
#     run(file = file,time = time,user = user )




# -*- encoding: utf-8 -*-
"""
@File    : analysis_openapi.py
@Time    : 2020/11/25 16:46
@Author  : Yu Tao
@Software: PyCharm
"""
from . import parse_tools
import yaml,sys

class OpenapiF(object):

    def __init__(self):
        self.path_list = parse_tools.Parse.find_file('temp', 'yaml')

    def source(self):
        try:
            for path in self.path_list:
                openapi = open(path, mode='r', encoding='utf-8')
                ojson = yaml.load(openapi, Loader=yaml.FullLoader)

                print (ojson)
                filename = path.split("\\")[-1].split('.')[0]
                data = {}
                data["request"] = {}
                print(ojson.get("servers")[0].get("url"))
                data["request"].update({"headers": []})
                data["request"].update({"bodySize":""})
                data["request"].update({"cookies":[]})
                for apath in ojson.get("paths").keys():
                    data["request"].update({"url": ojson.get("servers")[0].get("url") + apath})
                # data["request"].update({"method": ojson["request"]["method"]})
                data["request"].update({"httpVersion": ""})
                parse_tools.Parse.tmp(data, filename)
                openapi.close()
        except:
            print('获取openapi文件数据失败！')
            sys.exit()


# if __name__ == '__main__':
#
#     p = OpenapiF()
#     p.source()
#     Parse.source()
#     # tmp文件生成case
#     parse_tools.Parse.tmp_create_case()


# -*- coding: utf-8 -*-
# @File    : Shell.py

"""
封装执行shell语句方法

"""

import subprocess


class Shell(object):
    @staticmethod
    def invoke(cmd):
        output, errors = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE).communicate()
        o = output.decode("utf-8","ignore")
        return o



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    : case_generate.py
@Time    : 2020/10/16 10:39
@Author  : liyinlong
@Software: PyCharm
"""

import time
import os, re


class Generate(object):

    def __init__(self, data, case_name=None):
        self.data = data
        self.case_name = case_name

        #self.root_path = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        self.root_path = os.path.join(os.getcwd())
        if not os.path.exists(str(self.root_path) + '\\temp\\Testcase'):
            os.makedirs(str(self.root_path) + '\\temp\\Testcase')

    '''
    依据har文件method信息生成对应case
    如果传入文件名以传入文件名+数据在entries中的位置命名
    不传入文件名默认以path路径命名，截取path后两段命名
    如果没有path路径，以域名命名
    '''

    def case(self, path_lists=None):
        list = []
        method = ''
        keys = ''
        dump = ''
        # print(self.data)
        base_path = ""
        bk = 4 * " "
        for t, each in enumerate(self.data):
            print("*********************each:**********************:", each)
            # print("*********************self.data.get(each):**********************:", self.data.get(each))
            # 取出basePath
            if each == "basePath":
                if self.data.get(each) != "/":
                    base_path = self.data.get(each)
            # print("------base_path------:", base_path)
            list.append(each)
        paths = self.data.get('paths')
        local_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
        # print("****************self.data.get('paths')*****************",self.data.get('paths'))
        for t, each in enumerate(paths):
            # print("**********************each:*********************:", each)
            if path_lists and each not in path_lists:
                continue
            else:
                for n, m in enumerate(paths.get(each)):
                    method = m          # 取出请求方法
                    for c, cons in enumerate(paths.get(each).get(m)):
                        if cons == 'consumes':
                            if 'application/json' in str(paths.get(each).get(m).get('consumes')):
                                dump = 'params = json.dumps(params)'
                            else:
                                dump = ''
                parameters = paths.get(each).get(method).get('parameters')
                # 带bathpath时，需要在每个path前，加入bathpath的值
                # each = base_path + each
                # 不考虑bathpath
                each = each
                # print("=========================拼接basePath后的path:========================", each)
                if '{' in each and each[-1]=='}':    # 判断路径里是否有大括号，来拼接response内容
                    req = method.lower() + '(host+\"' + each.replace('{', '\"+ ').replace('}', ' +\"')[:-2] + ', params, header)'
                elif '{' in each and each[-1]!='}':
                    req = method.lower() + '(host+\"' + each.replace('{', '\"+ ').replace('}', ' +\"') + '/\", params, header)'
                else:
                    req = method.lower() + '(host+\"' + each + '\", params, header)'

                each = each.replace('{', '').replace('}', '')
                case_file_name = 'test' + each.replace('/', '_') + '.py'
                print("----------------case_generate-------------case_file_name:", case_file_name)
                key = []
                param_in_paths = []
                param_in_paths_value = []
                param_in_header = []
                param_in_header_value = []
                if 'securityDefinitions' in list:     # 判断securityDefinitions里是否有参数
                    if self.data.get('securityDefinitions'):
                        for a, b in enumerate(self.data.get('securityDefinitions')):
                            if self.data.get('securityDefinitions').get(b).get('name'):
                                in_where = self.data.get('securityDefinitions').get(b).get('in')
                                if in_where == 'body':
                                    param_in_paths.append(self.data.get('securityDefinitions').get(b).get('name'))
                                    key.append(re.sub(' +', '_',self.data.get('securityDefinitions').get(b).get('name').replace('-', '_')))
                                elif in_where == 'header':
                                    param_in_header.append(self.data.get('securityDefinitions').get(b).get('name'))
                                    key.append(re.sub(' +', '_',self.data.get('securityDefinitions').get(b).get('name').replace('-', '_')))
                                else:
                                    print("securityDefinitions类型异常")
                dict_param_inpath = ''
                dict_param_inheader = ''
                print("parameters-----------------------:", parameters)
                if parameters:
                    for num, param in enumerate(parameters):    # 将参数分别放进 params 和 header
                        name = ''
                        if param.get('name'):
                            name = param.get('name')
                            key.append(re.sub(' +', '_', name.replace('-', '_')))
                            keys = ', '.join(key)
                        if param.get('in'):
                            in_wh = param.get('in')
                        if in_wh == 'body':
                            param_in_paths.append(name)
                            param_in_paths_value.append(re.sub(' +', '_',name.replace('-', '_')))
                            dict_param_inpath = str(dict(zip(param_in_paths, param_in_paths_value))).replace(': \'',': ').replace('\',',',').replace('\'}','}')
                            if dict_param_inpath == "{'': }":
                                dict_param_inpath = "{}"
                        elif in_wh == 'header':
                            param_in_header.append(name)
                            param_in_header_value.append(re.sub(' +', '_',name.replace('-', '_')))
                            dict_param_inheader = "header.update(" + str(dict(zip(param_in_header, param_in_header_value))).replace(': \'',': ').replace('\',',',').replace('\'}','}') + ')'
                            if dict_param_inheader == "header.update({'': })":
                                dict_param_inheader = "header.update({})"
                        else:
                            pass
                else:
                    pass
                if dict_param_inpath == '':
                    dict_param_inpath = '{}'
                if keys:
                    keys = ', ' + keys + ','
                else:
                    keys = ','
                file_write = os.path.join(self.root_path, "TestCase", case_file_name)
                print("------------file_write----------------:", file_write)
                with open(file_write, 'w', encoding="utf-8") as outfile:
                    outfile.write("\"\"\"" + "\r")
                    outfile.write("@File    : %s" % case_file_name + "\r")
                    outfile.write("@Time    : %s" % local_time + "\r")
                    outfile.write("@Author  : Automatic generation" + "\r")
                    outfile.write("\"\"\"" + "\r")
                    outfile.write("#--别名占位" + "\r\r")
                    outfile.write("from accio import Http" + "\r\r\r")
                    outfile.write("import json" + "\r")
                    outfile.write("class Case:" + "\r\r")
                    outfile.write(bk + "def __init__(self):" + "\r")
                    outfile.write(2*bk + "self.request = Http.Request()" + "\r\r")
                    outfile.write(bk + "def request_method(self, host%s headers):" % keys + "\r")
                    outfile.write(2*bk + "\"\"\"")
                    outfile.write(3*bk + "用例描述：数据源文件中第 %s 个request" % str(t + 1) + "\r")
                    outfile.write(2*bk + "\"\"\"" + "\r")
                    outfile.write(2*bk + "params = %s" % dict_param_inpath + "\r")
                    outfile.write(2*bk + dump + "\r")
                    outfile.write(2*bk + "if not headers:" + "\r")
                    outfile.write(3*bk + "headers='{}'" + "\r")
                    outfile.write(2*bk + "header = eval(headers)" + "\r")
                    outfile.write(2*bk + "%s" % dict_param_inheader + "\r")
                    outfile.write(2*bk + "response = self.request.%s" % req + "\r")
                    outfile.write(2*bk + "return response" + "\r")
                    keys = ''

    def case_dubbo(self):
        """
        生成dubbo测试步骤文件
        :return:
        """
        lista = ["1"]
        bk = 4*" "
        for a in lista:
            local_time = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())
            # case_file_name = 'test' + each.replace('/', '_') + '.py'
            case_file_name = 'test001' + '.py'
            file_write = os.path.join(self.root_path, "TestCase", case_file_name)
            with open(file_write, 'w', encoding="utf-8") as outfile:
                outfile.write("\"\"\"" + "\r")
                outfile.write("@File    : %s" % case_file_name + "\r")
                outfile.write("@Time    : %s" % local_time + "\r")
                outfile.write("@Author  : Automatic generation" + "\r")
                outfile.write("\"\"\"" + "\r")
                outfile.write("#--别名占位" + "\r\r")
                outfile.write("from pyhessian.client import HessianProxy" + "\r")
                outfile.write("from pyhessian import protocol" + "\r\r\r")
                outfile.write("class Case(object):" + "\r\r")
                outfile.write(bk + "def request_method(url, interface, method, param_obj, **kwargs):" + "\r")
                outfile.write(2*bk + "req_param = protocol.object_factory(param_obj, **kwargs)" + "\r")
                outfile.write(2*bk + "req_obj = HessianProxy(url + interface)" + "\r")
                outfile.write(2*bk + "res = getattr(req_obj, method)(req_param)" + "\r")
                outfile.write(2*bk + "return res" + "\r")



# if __name__ == '__main__':
#     Generate("data").case_dubbo()


# -*- coding: utf-8 -*-
# @File    : Assert.py


"""
封装Assert方法

"""
from . import logger
from . import Consts
import json


class Assertions(object):
    def __init__(self):
        self.log = logger.MyLog()

    def code(self, code, expected_code):
        """
        验证response状态码
        :param code:
        :param expected_code:
        :return:
        """
        try:
            assert code == expected_code
            return True
        except:
            self.log.error("statusCode error, expected_code is %s, statusCode is %s " % (expected_code, code))
            Consts.RESULT_LIST.append('fail')

            raise

    def body(self, body, body_msg, expected_msg):
        """
        验证response body中任意属性的值
        :param body:
        :param body_msg:
        :param expected_msg:
        :return:
        """
        try:
            print("====body==============================>>>>", body)
            print("====body_msg============================>>>>>>", body_msg)
            msg = body[body_msg]
            assert msg == expected_msg
            return True

        except:
            self.log.error("Response body msg != expected_msg, expected_msg is %s, body_msg is %s" % (expected_msg, body_msg))
            Consts.RESULT_LIST.append('fail')

            raise

    def find_key(self, content, akey):
        if akey in content:
            return content[akey]
        else:
            for key in content.keys():
                if isinstance(content[key], list):
                    for alist in content[key]:
                        if isinstance(alist, dict):
                            return self.find_key(alist, akey)
                elif isinstance(content[key], dict):
                    return self.find_key(content[key], akey)
        return None

    def assert_body(self, real_body, excepte_dict):
        """
        :param self:
        :param body:
        :param excepte_dict:
        :return:
        """
        print("------assert_body-----:", type(excepte_dict),excepte_dict)
        try:
            excepte_dict = eval(excepte_dict)
            dict = {}
            for element_key in excepte_dict:
                real_value = self.find_key(content=real_body, akey=element_key)
                if type(real_value) == int or str(real_value) in ['true', 'false','null', 'True', 'False']:
                    real_value = str.lower(str(real_value))
                if real_value != "":
                    dict.update({element_key:real_value})
                else:
                    print("没找到key")
            print("校验结果dict------------------------------", dict)
            print("excepte_dict------------------------------", excepte_dict)
            assert excepte_dict == dict
            return True
        except:
            self.log.error("assertion error")
            Consts.RESULT_LIST.append('fail')
            raise

    def assert_string(self, expect_str, result):
        print("校验结果dict------------------------------", expect_str)
        print("excepte_dict------------------------------", result)
        try:
            assert expect_str == result
        except:
            self.log.error("assertion error")
            Consts.RESULT_LIST.append('fail')
            raise

    def assert_head_error(self, expect_str, result):
        print("校验结果dict------------------------------", expect_str)
        print("excepte_dict------------------------------", result)
        try:
            assert expect_str == result, "断言开头不是body或header!"
        except:
            self.log.error("assertion error")
            Consts.RESULT_LIST.append('fail')
            raise

    def in_body(self, body, body_msg, expected_msg):
        """
        验证response body中任意属性的值
        :param body:
        :param body_msg:
        :param expected_msg:
        :return:
        """
        try:
            msg = body[body_msg]
            assert expected_msg in msg
            return True

        except:
            self.log.error("Response body msg != expected_msg, expected_msg is %s, body_msg is %s" % (expected_msg, body_msg))
            Consts.RESULT_LIST.append('fail')

            raise


    def in_text(self, body, expected_msg):
        """
        验证response body中是否包含预期字符串
        :param body:
        :param expected_msg:
        :return:
        """
        try:
            text = json.dumps(body, ensure_ascii=False)
            # print(text)
            assert expected_msg in text
            return True

        except:
            self.log.error("Response body Does not contain expected_msg, expected_msg is %s" % expected_msg)
            Consts.RESULT_LIST.append('fail')

            raise

    def text(self, body, expected_msg):
        """
        验证response body中是否等于预期字符串
        :param body:
        :param expected_msg:
        :return:
        """
        try:
            assert body == expected_msg
            return True

        except:
            self.log.error("Response body != expected_msg, expected_msg is %s, body is %s" % (expected_msg, body))
            Consts.RESULT_LIST.append('fail')

            raise

    def time(self, time, expected_time):
        """
        验证response body响应时间小于预期最大响应时间,单位：毫秒
        :param body:
        :param expected_time:
        :return:
        """
        try:
            assert time < expected_time
            return True

        except:
            self.log.error("Response time > expected_time, expected_time is %s, time is %s" % (expected_time, time))
            Consts.RESULT_LIST.append('fail')

            raise





# -*- encoding: utf-8 -*-
"""
@File    : parse_tools.py
@Time    : 2020/10/19 11:22
@Author  : liyinlong
@Software: PyCharm
"""

import os
import sys
import base64
import codecs
from . import case_generate,config_file_parser
import re


class Parse(object):

    @staticmethod
    def find_file(folder, formats):
        """
        查找指定目录指定文件格式文件
        :param folder: 文件夹路径
        :param formats: 文件名后缀
        :return: 文件路径list
        """
        file_list = []
        # root_path = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        root_path=Parse.get_rootpath()
        file_path = os.path.join(root_path, folder)
        if not os.path.exists(file_path):
            os.makedirs(file_path)

        path_list = []
        f_list = os.listdir(file_path)
        try:
            for i in f_list:
                if os.path.splitext(i)[1] == '.' + str(formats.lower()):
                    file_list.append(i)
            for f in file_list:
                path = file_path + '/'+str(f)
                path_list.append(path)
            return path_list
        except:
            print('请确认temp文件夹下是否存在.%s 后缀文件！' % str(formats.lower()))
            sys.exit()

    @staticmethod
    def headers(data):
        """
        数据转成字典格式
        :param data:
        :return:
        """
        headers = {}
        for each in data:
            k, v = each.values()
            if k in ['Cookie']:
                continue
            headers.setdefault(k, v)
        return headers

    @staticmethod
    def post_data(post_data):
        """
        数据转成字典格式
        :param post_data:
        :return:
        """
        data = {}
        for each in post_data:
            k, v = each.values()
            data.setdefault(k, v)
        return data

    @staticmethod
    def post_data_key(request, t):
        """
        提取postData中的key
        :param request: 请求
        :param t: 该请求在请求列表中的位置
        :return: key list
        """
        key_list = []
        if 'postData' in request:
            if 'text' in request.get('postData'):
                body = request.get('postData').get('text')
                try:
                    body = eval(body)
                    key_list = list(body.keys())
                except(SyntaxError, ValueError):
                    print('提取key失败，请确认第 '+str(t)+' 个请求的postData中text格式！')
            else:
                body = request.get('postData').get('params')
                if body is not None:
                    for i in body:
                        key = i.get('name')
                        if key is not None:
                            key_list.append(key)
        return key_list

    @staticmethod
    def base64decode(text):
        """
        base64格式转码
        :param text:
        :return:
        """
        missing_padding = 4 - len(text) % 4
        if missing_padding:
            text += '=' * missing_padding
        return base64.b64decode(text).decode("utf-8")

    @staticmethod
    def path(path):
        """
        提取path后两段
        :param path:
        :return:
        """
        path_res = '_'.join(path.split('/')[-3:])
        return path_res

    @staticmethod
    def tmp(data, filename):
        """
        生成tmp格式临时文件
        :param data: tmp文件内容
        :param filename: tmp文件名
        """
        # root_path = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        root_path = os.path.join(os.getcwd())
        file_path = root_path + '/temp/Tempdata'

        if not os.path.exists(file_path):
            os.makedirs(file_path)
        file = os.path.join(root_path, "temp/Tempdata", filename+'.tmp')
        with open(file, 'w', encoding="utf-8") as outfile:
            outfile.write(str(data))

    @staticmethod
    def read_tmp(tmpfile):
        """
        读取tmp文件
        :param tmpfile: tmp文件路径
        :return:
        """
        file = codecs.open(tmpfile, mode='r', encoding='utf-8-sig')
        data = eval(file.read())
        file.close()
        return data

    @staticmethod
    def tmp_create_case(type="0", path_lists=None):
        """
        temp\\Tempdata目录下tmp文件生成case
        :param type:
        :return:
        """
        root=Parse.get_rootpath()
        rootpath=os.path.join(root, 'temp/Tempdata')
        tmp_path_list = Parse.find_file(rootpath, 'tmp')
        for tmpfile in tmp_path_list:
            data = Parse.read_tmp(tmpfile)
            if type=="0":
                case_generate.Generate(data).case(path_lists)
            else:
                case_generate.Generate(data).case_dubbo()
            new_name = tmpfile + '_over'
            try:
                os.rename(tmpfile, new_name)
            except FileExistsError:
                os.remove(new_name)
                os.rename(tmpfile, new_name)

    @staticmethod
    def find_casefile(folder, f_list):
        """
        查找TestCase目录下面指定文件格式的文件
        :param folder：文件路径:
        :param formats: 文件名前缀
        :return: 查找到文件list
        """
        try:
            file_list1 = []
            for i in f_list:
                if not i.find('test_'):
                    file_list1.append(i)

            return  file_list1
        except:
            print('请确认TestCase文件夹下是否存在test 前缀文件！')
            sys.exit()

    @staticmethod
    def extract_key(contents_str):
        """
        查找TestCase目录下面
        :param folder：文件路径:
        :param formats: 文件名前缀
        :return: 查找到文件list
        """

        try:
            # list_key_dict={}
            pramlist = re.findall(r'{.*}', contents_str)
            list_key_dict = eval(pramlist[0].replace(': ', ': "').replace(',', '",').replace('}', '"}'))

            # print(list_key_dict)
            return list_key_dict
        except:
            print('请确认TestCase文件夹下是否存在testcase文件！')
            sys.exit()

    @staticmethod
    def get_rootpath():
        return os.path.join(os.getcwd())

    @staticmethod
    def get_global_value(self, excel_value, global_file):
        print("excel_value:", excel_value)
        print("global_conf:", global_file)
        global_conf = config_file_parser.ConfigFileParser(global_file)
        # 通过正则表达式，获取匹配到全局变量${}
        find_re = re.compile(r'(\${.*?\})', re.S)
        re_find = re.findall(find_re, excel_value)
        # 将全局变量值替换掉${}格式的字符串
        for value in re_find:
            if 'int' in global_conf.get_value('global', value.replace('${', '').replace('}', '')).split('&')[1].strip():
                 excel_value=excel_value.replace(value, global_conf.get_value('global',value.replace('${','').replace('}','')).split('&')[0].strip()).replace('\'','').replace('\"','')
                 print("if获取到的是：",excel_value)
            else:
                 excel_value=excel_value.replace(value, global_conf.get_value('global',value.replace('${','').replace('}','')).split('&')[0].strip())
                 print("else获取到的是：", excel_value)
        print("要return的是：", excel_value)
        return excel_value


# if __name__ == '__main__':
#     Parse.tmp('aaaa', 'test')







# -*- encoding: utf-8 -*-
"""
@File    : ConfigFIleParser.py
@Time    : 2020/9/3 9:44
@Author  : Yu Tao
@Software: PyCharm
"""


import os
from configparser import ConfigParser, NoSectionError, NoOptionError, MissingSectionHeaderError
from accio.return_code import _init_err_code, get_err_code
# from accio.Log import MyLog


class ConfigFileParser(object):

    def __init__(self, file=None):
        """
        初始化
        :param file: 配置文件路径，默认为根路径下ini文件
        """
        _init_err_code()
        # self.log = self.get_log()
        self.configer = ConfigParser()
        self.file = file
        if not os.path.exists(file):
            raise FileNotFoundError("请确保配置文件存在！")
        try:
            self.configer.read(file, encoding='utf-8')
        except :
            # self.log.debug(get_err_code("20002"))
            print(get_err_code("20002"))

    def get_value(self, title, key):
        """
        获取配置文件中的值
        :param title:
        :param key:
        :return:
        """
        # global config
        try:
            the_value = self.configer.get(title, key)
        except NoSectionError:
            # self.log.error(get_err_code("20003"))
            print(get_err_code("20003"))
            the_value = "error"
        except NoOptionError:
            # self.log.error(get_err_code("20004"))
            print(get_err_code("20004"))
            the_value = "error"
        return the_value

    def set_value(self, title, key, value):
        """
        设置配置文件中的键值
        :param title:
        :param key:
        :param value:
        :return:
        """
        # global config
        self.configer.set(title, key, value)

    def get_config_ini(self):
        # rootPath = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        # file = os.path.join(rootPath, "config.ini")
        file = os.path.join(os.getcwd(), "configer.ini")
        self.configer = ConfigParser()
        if not os.path.exists(file):
            raise FileNotFoundError("请确保配置文件存在！")
        try:
            self.configer.read(file, encoding='utf-8')
        except:
            # self.log.debug(get_err_code("20002"))
            print(get_err_code("20002"))

    def write_config_ini(self, section, option, value):
        try:
            configer = self.configer
            configer.set(section, option, value)
            configer.write(open(self.file, "w", encoding='UTF-8'))
        except:
            print("更新ini文件失败！")


class ConfigFileParserIni(ConfigFileParser):

    def __init__(self):
        """
        加载框架级配置文件configer
        """
        # rootPath = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        # file = os.path.join(rootPath, "configer.ini")
        file = os.path.join(os.getcwd(), "configer.ini")
        super().__init__(file)


# if __name__ == '__main__':
#     print(ConfigFileParserIni().get_value("scheduler", "time_pattern"))



# -*- encoding: utf-8 -*-
"""
@File    : case_parameter.py
@Time    : 2020/10/16 10:43
@Author  : liyinlong
@Software: PyCharm
"""

import json
import os
import xlwt
from . import parse_tools


class Parameter(object):

    def __init__(self, data, excel_path=None):
        self.__data = data
        # self.root_path = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        self.root_path = os.path.dirname(os.path.join(os.getcwd()))
        if excel_path is None:
            excel_path = self.root_path + '\\test_case.xls'
        self.excel_path = excel_path

    '''
    获取request的参数生成excel
    参数：url，method，headers，postData
    调用时需要传入excel保存路径
    '''

    def make_case_excel(self):
        # url_list = []
        request_list = []
        requests_list = []
        for each in self.__data:
            request = each.get('request')
            url = request.get('url')
            # if url in url_list:
            #     continue
            # url_list.append(url)
            request_list.append(url)
            method = request.get('method').lower()
            request_list.append(method)

            post_data = {}
            if method == "post":
                if 'params' in request['postData']:
                    post_data = parse_tools.Parse.post_data(request['postData']['params'])
                elif 'text' in request['postData']:
                    text = request['postData']['text']
                    try:
                        post_data = json.loads(text)
                    except:
                        post_data = text
            request_list.append(str(post_data))
            request_list = ['项目名称', '用例描述'] + request_list
            requests_list.append(request_list)
            headers = parse_tools.Parse.headers(request['headers'])
            request_list.append(str(headers))
            request_list = []
        excel_title = ['case_project', 'case_description', 'case_url', 'case_method', 'case_params', 'case_headers',
                          'real_key', 'expect_value', 'other']

        style = xlwt.XFStyle()
        alignment = xlwt.Alignment()
        alignment.wrap = 1
        alignment.vert = 0x01
        font = xlwt.Font()
        font.name = 'Times New Roman'
        font.bold = True
        font.color_index = 4
        font.height = 250
        style.font = font
        style2 = xlwt.XFStyle()
        style2.alignment = alignment

        f = xlwt.Workbook()
        sheet1 = f.add_sheet('case', cell_overwrite_ok=True)
        for wid in range(len(excel_title)):
            sheet1.col(wid).width = 7999

        for t in range(len(excel_title)):
            sheet1.write(0, t, excel_title[t], style)

        i = 1
        for data in requests_list:
            for j in range(len(data)):
                sheet1.write(i, j, data[j], style2)
            i = i + 1
        f.save(self.excel_path)


# if __name__ == '__main__':
#     from accio import har_analysis
#     data = har_analysis.Har().source()
#     Parse = Parameter(data)
#     Parse.make_case_excel()



# coding=utf8
# !/usr/bin/env python
# __author_='crisschan'
# __data__='20160908'
# __from__='EmmaTools https://github.com/crisschan/EMMATools'
# __instruction__= 测试需要处理字符串的类:
#           修改了方法添加了@classmethod装饰器
import random
import re


class TestString(object):
    def __GetMiddleStr(self,content, startPos, endPos):
        '''
        :根据开头和结尾字符串获取中间字符串
        :param content:原始string
        :param startPos: 开始位置
        :param endPos: 结束位置
        :return: 一个string
        '''
        # startIndex = content.index(startStr)
        # if startIndex >= 0:
        #    startIndex += len(startStr)
        # endIndex = content.index(endStr)
        return content[startPos:endPos]

    def __Getsubindex(self,content, subStr):
        '''
        :param content: 原始string
        :param subStr: 字符边界
        :return:  字符边界出现的第一个字符的在原始string中的位置 []
        '''
        alist = []

        asublen = len(subStr)
        sRep = ''
        istep = 0
        while istep < asublen:
            if random.uniform(1, 2) == 1:
                sRep = sRep + '~'
            else:
                sRep = sRep + '^'
            istep = istep + 1


        apos = content.find(subStr)
        while apos >= 0:
            alist.append(apos)
            content = content.replace(subStr, sRep, 1)

            apos = content.find(subStr)
        return alist

    @classmethod
    def GetTestString(cls_obj,content, startStr, endStr):
        '''
        :param content: 原始string
        :param startStr: 开始字符边界
        :param endStr: 结束字符边界
        :return: 前后边界一致的中间部分字符串 []
        '''
        reStrList = []
        if content is None or content=='':
            return reStrList
        if startStr!='' and content.find(startStr)<0:
            startStr=''
        if endStr!='' and content.find(endStr)<0:
            endStr=''

        if startStr=='':
            reStrList.append(content[:content.find(endStr)])
            return reStrList
        elif endStr=='':
            reStrList.append(content[content.find(startStr)+len(startStr):])
            return reStrList
        elif startStr=='' and  endStr=='':
            reStrList.append(content)
            return reStrList
        else:
            starttemplist = cls_obj().__Getsubindex(content, startStr)

            nStartlen = len(startStr)
            startIndexlist = []
            for ntemp in starttemplist:
                startIndexlist.append(ntemp + nStartlen)
            endIndexlist = cls_obj().__Getsubindex(content, endStr)

            astep = 0
            bstep = 0
            dr = re.compile(r'<[^>]+>', re.S)

            while astep < len(startIndexlist) and bstep < len(endIndexlist):
                while startIndexlist[astep] >= endIndexlist[bstep]:
                    bstep = bstep + 1
                strTemp = cls_obj().__GetMiddleStr(content, startIndexlist[astep], endIndexlist[bstep])
                strTemp = dr.sub('', strTemp)

                reStrList.append(strTemp)
                astep = astep + 1
                bstep = bstep + 1

            return reStrList

# if __name__ == "__main__":
#     strgg = '24214jnjkanrhquihrghjw<>eufhuin/jfghs<><a href=ajfjsanfghj/kg/hjkghj<>kghjfasd/sdaf'
#     print(TestString.GetTestString(strgg,'14','/'))


# -*- encoding: utf-8 -*-
"""
@File    : Module_detection.py
@Time    : 2020/9/30 10:42
@Author  : liyinlong
@Software: PyCharm
"""
import re
import os
import sys
from . import logger, parse_tools


class Module(object):

    def __init__(self):
        self.root_path=parse_tools.Parse.get_rootpath()
        # self.root_path = str(os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir)))
        self.file = os.path.join(self.root_path, "requirements.txt")
        if not os.path.exists(self.file):
            raise FileNotFoundError("请确保requirements文件存在！")
        self.log = logger.MyLog()

    def module_detection(self):
        with open(self.file, 'r') as e:
            f = e.read()
            list_m = f.strip('\n').split('\n')
            for i in list_m:
                try:
                    m_name = re.findall(r'(.+?)\=', i)[0]
                    print("正在检测 %s 模块" % m_name)
                    show_m = os.system('pip show %s' % m_name)
                    print(show_m)
                    if show_m != 0:
                        print("正在安装 %s 模块" % m_name)
                        install_m = os.system("pip install %s" % i)
                        if install_m != 0:
                            print("%s 模块安装失败" % m_name)
                            sys.exit(1)

                except:
                    self.log.error("-----模块检测出现异常！----")
                    print('模块检测出现异常！')


# if __name__ == "__main__":
#     k = Module()
#     k.module_detection()



# -*- encoding: utf-8 -*-
from . import parse_tools
import sys


class Swagger(object):

    def source(self, swagger_json, path_lists=None):
        """
        生成测试用例
        :param swagger_json:
        :return:
        """
        try:
            parse_tools.Parse.tmp(swagger_json, 'a')
            parse_tools.Parse.tmp_create_case(type="0", path_lists=path_lists)
        except Exception as ex:
            print('获取swagger文件数据失败！')
            print(ex)
            sys.exit()



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    : analysis_har.py
@Time    : 2020/10/13 14:21
@Author  : liyinlong
@Software: PyCharm
"""
import sys
from urllib.parse import urlparse
from . import parse_tools


class Har(object):

    def source(self, har_json):
        """
        生成测试用例
        :param har_json:
        :return:
        """
        try:
            swagger_json, path_list = self.format_data(har_json)
            parse_tools.Parse.tmp(swagger_json, 'a')
            parse_tools.Parse.tmp_create_case()
            # swagger_json参数表入参
            return path_list, swagger_json
        except Exception as ex:
            print('获取har文件数据失败！')
            print(ex)
            sys.exit()

    def format_data(self, har_json):
        """
        格式化数据，使其满足“用例生成”的调用要求
        :param har_json: 读出的har文件数据
        :return:
        """
        entries = har_json.get("log").get("entries")
        template_data = {"swagger": "2.0"}
        template_data.update({"basePath": ""})
        template_data.update({"paths": {}})
        consumes = []
        path_list = []
        for entrie in entries:
            request = entrie.get("request")
            method = request.get("method").lower()
            url = request.get("url")
            path = urlparse(url).path
            path_list.append(path)
            headers = request.get("headers")
            query_string = request.get("queryString")
            if headers:
                for head in headers:
                    if head.get("name") == "Content-Type":
                        consumes.append(head.get("value"))
            parameters = []
            if query_string:
                for query_data in query_string:
                    parameters.append({"name": query_data.get("name"), "in": "body"})
            post_data = request.get("postData")
            if post_data:
                text = post_data.get("text")
                for key in eval(text).keys():
                    parameters.append({"name": key, "in": "body"})
            template_data["paths"].update({path: {}})
            template_data["paths"][path].update({method: {"parameters": parameters, "consumes": consumes}})
            consumes = []
        return template_data, path_list




#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@File    : logger.py
@Time    : 2020/12/29 9:42
@Author  : Yu Tao
@Software: PyCharm
"""
import os
import time
import logging
import inspect
from logging.handlers import RotatingFileHandler

class MyLog(object):
    def create_handlers(self, path):
        dir_log = path
        dir_time = time.strftime('%Y-%m-%d', time.localtime())
        handlers = {logging.NOTSET: os.path.join(dir_log, 'notset_%s.log' % dir_time),

                    logging.DEBUG: os.path.join(dir_log, 'debug_%s.log' % dir_time),

                    logging.INFO: os.path.join(dir_log, 'info_%s.log' % dir_time),

                    logging.WARNING: os.path.join(dir_log, 'warning_%s.log' % dir_time),

                    logging.ERROR: os.path.join(dir_log, 'error_%s.log' % dir_time),

                    logging.CRITICAL: os.path.join(dir_log, 'critical_%s.log' % dir_time),
                    }
        log_levels = handlers.keys()

        for level in log_levels:
            path = os.path.abspath(handlers[level])
            handlers[level] = RotatingFileHandler(path, maxBytes=10000, backupCount=2, encoding='utf-8')
        return handlers

    def get_now(self):
        return time.strftime('%Y-%m-%d %H:%M:%S', time.localtime())

    def __init__(self,path = os.path.join(os.path.join(os.getcwd(), os.path.pardir, 'Log')), level=logging.NOTSET):
        handlers = self.create_handlers(path)
        self.__loggers = {}
        log_levels = handlers.keys()
        for level in log_levels:
            logger = logging.getLogger(str(level))
            logger.addHandler(handlers[level])
            logger.setLevel(level)
            self.__loggers.update({level: logger})

    def get_log_message(self, level, message):
        frame, filename, lineNo, functionName, code, unknowField = inspect.stack()[2]
        '''日志格式：[时间] [类型] [记录代码] 信息'''
        return "[%s] [%s] [%s - %s - %s] %s" % (self.get_now(), level, filename, lineNo, functionName, message)

    def info(self, message):
        message = self.get_log_message("info", message)
        self.__loggers[logging.INFO].info(message)

    def error(self, message):
        message = self.get_log_message("error", message)
        self.__loggers[logging.ERROR].error(message)

    def warning(self, message):
        message = self.get_log_message("warning", message)
        self.__loggers[logging.WARNING].warning(message)

    def debug(self, message):
        message = self.get_log_message("debug", message)
        self.__loggers[logging.DEBUG].debug(message)

    def critical(self, message):
        message = self.get_log_message("critical", message)
        self.__loggers[logging.CRITICAL].critical(message)


if __name__ == "__main__":
    logger = MyLog()
    logger.info("info")



# -*- coding: utf-8 -*-


'''
关于Excel表的操作
'''

import xlrd
from . import logger


class Excel(object):
    def __init__(self):
        self.log = logger.MyLog()

    def get_excel_data(self, path, sheet_num=0):
        """
        :param path: Excel文件路径
        :param sheet_num: Sheet页码，默认值为0
        :return:
        """
        try:
            # 获取到book对象
            book = xlrd.open_workbook(path)
            # 获取sheet对象
            sheet = book.sheet_by_index(sheet_num)
            rows, cols = sheet.nrows, sheet.ncols
            l = []
            title = sheet.row_values(0)
        except:
            self.log.error('请检查Excel文件路径或Sheet页码是否正确！')
            print('请检查Excel文件路径或Sheet页码是否正确！')

        # 获取其他行
        for i in range(1, rows):
            # print(sheet.row_values(i))
            l.append(dict(zip(title, sheet.row_values(i))))
        return l



#!/usr/bin/env python
# -*- encoding: utf-8 -*-
"""
@Time    : 2021/4/20 8:34
@Software: PyCharm
"""

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="accio_api",  # 包的名字
    version="0.0.2",  # 版本号
    author="accio",  # 作者
    author_email="xx@example.com",
    description="accio",  # 描述
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://pypi.org/project/accio-api/",  # 可以写github上的地址，或者其他地址

    # 依赖包
    install_requires=[
        'pytest',
        'requests',
    ],
    # project_urls={
    #     "Bug Tracker": "https://github.com/pypa/sampleproject/issues",
    # },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages = setuptools.find_packages('src'),
    package_dir={"": "src"},
    package_data = {
            # 任何包中含有.txt文件，都包含它
            '': ['*.txt'],
            # 包含demo包data文件夹中的 *.dat文件
            # 'demo': ['data/*.dat'],
        },


# include_package_data = True,
    # packages=setuptools.find_packages(exclude=['test', 'examples', 'script', 'tutorials']),  # 包内不需要引用的文件夹
    # packages=setuptools.find_packages(exclude=["Assert.py"]),
    # packages=setuptools.find_packages(where="yttttttttttttttttttttttttttttt"),
    python_requires=">=3.6",
)


# -*- coding: utf-8 -*-
# @File    : Email.py

"""
封装发送邮件的方法

"""
import smtplib
import time
from email.header import Header
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
from . import Consts
from . import logger
from . import config_file_parser


class SendMail(object):

    def __init__(self):

        # self.config = Config()
        self.log = logger.MyLog()

    def sendMail(self):
        conf = config_file_parser.ConfigFileParserIni()
        msg = MIMEMultipart()
        f = open('./Report/email/test_report.html', 'rb')
        mail_body = f.read()
        f.close()
        mail_body2 = MIMEText(mail_body, 'html', 'utf-8')
        # body = """
        # <h3>Hi，all</h3>
        # <p>本次接口自动化测试报告如下。</p>
        # """
        # mail_body = MIMEText(body, _subtype='html', _charset='utf-8')
        # stress_body = Consts.STRESS_LIST
        # result_body = Consts.RESULT_LIST
        # body2 = 'Hi，all\n本次接口自动化测试报告如下：\n   接口响应时间集：%s\n   接口运行结果集：%s' % (stress_body, result_body)
        # mail_body2 = MIMEText(body2, _subtype='plain', _charset='utf-8')
        tm = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))
        msg['Subject'] = Header("接口自动化测试报告"+"_"+tm, 'utf-8')
        msg['From'] = conf.get_value('mail', 'sender')
        receivers = conf.get_value('mail', 'receiver')
        toclause = receivers.split(',')
        msg['To'] = ",".join(toclause)
        # msg.attach(mail_body)

        msg.attach(mail_body2)

        try:
            smtp = smtplib.SMTP()
            smtp.connect(conf.get_value('mail', 'smtpserver'))
            smtp.login(conf.get_value('mail', 'username'), conf.get_value('mail', 'password'))
            smtp.sendmail(self.config.sender, toclause, msg.as_string())
        except Exception as e:
            print(e)
            print("发送失败")
            self.log.error("邮件发送失败，请检查邮件配置")

        else:
            print("发送成功")
            self.log.info("邮件发送成功")
        finally:
            smtp.quit()



# -*- encoding: utf-8 -*-
"""
@File    : ReturnCode.py
@Time    : 2020/9/7 11:19
@Author  : Yu Tao
@Software: PyCharm
"""


def _init_err_code():
    """
    初始化异常返回码字典
    通用异常返回码10001-19999
    文件读取类异常返回码20001-29999
    :return:
    """
    global glo_err_code
    glo_err_code = {"10001":"ParmisEmpty，参数为空",
                    "10002":"CallFunctionFail，调用方法异常",
                    "10003":"OtherError，其他异常",
                    "20001":"FileNotFound，文件没有找到",
                    "20002":"MissingSectionHeaderError，文件不符合格式或字符集编码有问题",
                    "20003":"NoSectionError，title没有找到",
                    "20004":"NoOptionError，key没有找到",
                    }


def set_err_code(key, value):
    """
    设置异常返回码
    :param key: 键
    :param value: 值
    :return:
    """
    glo_err_code[key] = value


def get_err_code(key):
    """
    获取异常返回码
    :param key: 键
    :return: 值
    """
    # from accio import Log
    # log = Log.MyLog()
    try:
        return glo_err_code[key]
    except KeyError:
        # log.error("key错误")
        print("key错误")








#！/usr/bin/env python
# -*- encoding: utf-8 -*-
# @Time : 2021/2/5 14:12
# @Author : Cuiluming
# @File : test.py
# @Software: PyCharm
from xlrd import xldate_as_tuple
from datetime import datetime
import xlrd
import os,queue
from operator import itemgetter
# import accio.locust_run

class file_analysis(object):
    @staticmethod
    def creatparm(project_name,loadfile):
            root_path = os.path.join(os.getcwd())
            book = xlrd.open_workbook(os.path.join(str(root_path),'projects',project_name,'Params', 'Excel',loadfile))
            # book =xlrd.open_workbook("F:\\accio_ui\\projects\\www24\\Params\\Excel\\performance_1612409441.xls")
            # 获取第一个sheet页
            sheet1 = book.sheets()[0]
            # 获取总行数
            rows = sheet1.nrows
            # 获取总列数
            cols = sheet1.ncols
            # print(cols)
            col_dict = {}
            for i in range(sheet1.ncols):
                col_dict[sheet1.cell_value(0, i)] = i
                # print(i)
                # print(col_dict.keys())
            # 输出每一列数据
            all_content = []
            for i in range(cols):
                col_content = []
                j = 1
                for j in range(rows):
                    ctype = sheet1.cell(j, i).ctype  # 表格的数据类型
                    # ctype = sheet1.cell(i, j).ctype
                    cell = sheet1.cell_value(j, i)  # 取第i列第j行数据
                    if ctype == 2 and cell % 1 == 0:  # 如果是整形
                        cell = int(cell)
                    elif ctype == 3:  # 如果是日期型
                        # 转成datetime对象
                        date = datetime(*xldate_as_tuple(cell, 0))
                        cell = date.strftime('%Y/%d/%m %H:%M:%S')
                    elif ctype == 4:  # 如果是boolean型
                        cell = True if cell == 1 else False
                    elif ctype==1:# 如果是str
                        cell=cell
                    col_content.append(cell)
                all_content.append(col_content)
            # print(all_content)
            new_dict = {}
            listkey = []
            for key in col_dict.items():
                listkey.append(list(key))
            count = 0
            for i in all_content:
                tem_list = []
                for j in i[1:]:
                    tem_list.append(j)
                new_dict[listkey[count][0]] = tem_list
                # print(new_dict)
                count += 1

            # 获取sheet对象
            sheet = book.sheet_by_index(0)
            rows, cols = sheet.nrows, sheet.ncols
            title = sheet.row_values(0)
            # print(title)
            return new_dict,title

    @staticmethod
    def put_queue_data(new_dict,title):
        class_list = []
        title_list = []
        for i in title:
            j=i.split(".")
            class_list.append(j[0])
            title_list.append(j[1])
        # 去重之后的class_list
        class_list=sorted(set(class_list), key=class_list.index)
        queue_parm_count = []
        queue_assert_count = []
        for i in range(len(class_list)):
            queue_parm_count.append("queue_data_parm{0}".format(i+1))
            queue_assert_count.append("queue_data_assert{0}".format(i+1))

        re_str = ""
        jshu = 0
        re_str_assert = ""
        index_class_list = 0 #下标
        key_list = []
        for k, v in new_dict.items():
            key_list.append(k)
            # 一次读入多列值
        out = itemgetter(*key_list)(new_dict)
        max_len = 0
        for i in out:
            if max_len < len(i):
                max_len = len(i)
        for s in range(len(class_list)):
            re_str = ""
            re_str_assert = ""
            data = [x for j, x in enumerate(title) if x.find(class_list[s]) != -1]

            print(data)
            for i in data:
                if i.find('expect_value')>=0 :
                    # 增加断言
                    re_str_assert = re_str_assert + "\"expect_value\"" + ":out[" + str(jshu) + "][count]"
                else:
                    re_str = re_str + "\"" + i.split(".")[1] + "\"" + ":out[" + str(jshu) + "][count]" + ","
                    jshu += 1

            re_str =  "params = {"+re_str[:-1]+"}"
            re_str_assert =  "params = {"+re_str_assert[:-1]+"}"
            jshu += 1
            count = 0
            for i in range(max_len):
                for j in range(len(data)):
                    i.split(".")[1]:out[j][count]
                    count += 1
            #     queue_data_parm1.put_nowait(params)


            # queue_parm_count[s]= queue.Queue()
            # queue_assert_count[s]= queue.Queue()


        # return queue_data_parm1, queue_data_assert1, queue_data_parm2, queue_data_assert2




if __name__ == '__main__':
    f=file_analysis()
    new_dict,title = f.creatparm("www24",loadfile="loadfile.xlsx")
    f.put_queue_data(new_dict,title)

